@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 
@@ -35,7 +21,7 @@ namespace KGAPI2
 namespace Drive
 {
 
-class KGAPIDRIVE_EXPORT PermissionDeleteJob :  KGAPI2::DeleteJob
+class KGAPIDRIVE_EXPORT PermissionDeleteJob :  public KGAPI2::DeleteJob
 {
     Q_OBJECT
 
@@ -74,12 +60,28 @@ class KGAPIDRIVE_EXPORT PermissionDeleteJob :  KGAPI2::DeleteJob
      */
     KGAPIDRIVE_DEPRECATED void setSupportsAllDrives(bool supportsAllDrives);
 
+    /**
+     * @brief Issue the request as a domain administrator; if set to true,
+     * then the requester will be granted access if the file ID parameter refers
+     * to a shared drive and the requester is an administrator of the domain to
+     * which the shared drive belongs. (Default: false)
+     */
+    bool useDomainAdminAccess() const;
+
+    /**
+     * @brief Sets to issue the request as a domain administrator; if set to true,
+     * then the requester will be granted access if the file ID parameter refers
+     * to a shared drive and the requester is an administrator of the domain to
+     * which the shared drive belongs. (Default: false)
+     */
+    void setUseDomainAdminAccess(bool useDomainAdminAccess);
+
   protected:
     void start() override;
 
   private:
     class Private;
-    Private *const d;
+    QScopedPointer<Private> d;
     friend class Private;
 };
 
